archive

package
v0.0.0-...-b84eec1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2020 License: GPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

const (
	KindProxeusProcess = "process"

	Thumb          = "thumb"
	ThumbEncrypted = "thumb_encrypted"
)

Variables

var ErrNoProxeusArchive = errors.New("not a Proxeus archive")
var ErrWhenParsingProxeusMeta = errors.New("error when parsing Proxeus meta")

Functions

func Tar

func Tar(src string, writer io.Writer) error

Tar takes a source and variable writers and walks 'source' writing each file found to the tar writer; the purpose for accepting multiple writers is to allow for multiple outputs (for example a file, or md5 hash)w

func TarFileList

func TarFileList(proxMetaArmoured []byte, srcList []string, writer io.Writer) error

Tar takes a source and variable writers and walks 'source' writing each file found to the tar writer; the purpose for accepting multiple writers is to allow for multiple outputs (for example a file, or md5 hash)w

func Untar

func Untar(dst string, r io.Reader) (err error)

Types

type ProxeusMeta

type ProxeusMeta struct {
	Version     int
	Kind        string
	FileNameMap map[string]string
	ProcessName string
}

func UntarProxeusArchive

func UntarProxeusArchive(dst string, r io.Reader, pw, pgpPriv []byte) (pm *ProxeusMeta, err error)

Untar takes a destination path and a reader; a tar reader loops over the tarfile creating the file structure at 'dst' along the way, and writing any files

Jump to