Documentation
¶
Index ¶
Constants ¶
const ( KindProxeusProcess = "process" Thumb = "thumb" ThumbEncrypted = "thumb_encrypted" )
Variables ¶
var ErrNoProxeusArchive = errors.New("not a Proxeus archive")
var ErrWhenParsingProxeusMeta = errors.New("error when parsing Proxeus meta")
Functions ¶
func Tar ¶
Tar takes a source and variable writers and walks 'source' writing each file found to the tar writer; the purpose for accepting multiple writers is to allow for multiple outputs (for example a file, or md5 hash)w
func TarFileList ¶
Tar takes a source and variable writers and walks 'source' writing each file found to the tar writer; the purpose for accepting multiple writers is to allow for multiple outputs (for example a file, or md5 hash)w
Types ¶
type ProxeusMeta ¶
type ProxeusMeta struct {
Version int
Kind string
FileNameMap map[string]string
ProcessName string
}
func UntarProxeusArchive ¶
Untar takes a destination path and a reader; a tar reader loops over the tarfile creating the file structure at 'dst' along the way, and writing any files
Click to show internal directories.
Click to hide internal directories.